/****************************************************************************
*
*  Avoid.c
*
*  AvoidEdge and AvoidTilt
*
****************************************************************************/

#pragma chip PIC16F877

// ---- Include Files -------------------------------------------------------

#include "Avoid.h"
#include "Debug.h"
#include "Delay.h"
#include "Motor.h"
#include "Sensor.h"
#include "Tilt.h"
#include "Puts.h"

// ---- Private Constants and Types -----------------------------------------
// ---- Private Variables ---------------------------------------------------
// ---- Private Function Prototypes -----------------------------------------
// ---- Functions -----------------------------------------------------------

/****************************************************************************
*
*  AvoidTilt
*
*  Backs away from being tilted
*/

extern void AvoidTilt( void )
{
   uns8  i;

#if DEBUG

   puts( "AvoidTilt: TX: " );
   putu8( gTiltX );
   puts( " TY: " );
   putu8( gTiltY );
   puts( " TS: " );
   putu8( gTiltState );
   puts( "\n" );
#endif

   if (( gTiltState & TILTED_LEFT ) != 0 )
   {
      DBG( puts( "Tilted Left\n" ); )

      gSpeedL = SPEED_BWD;
      gSpeedR = SPEED_FWD;
   }
   else
   if (( gTiltState & TILTED_RIGHT ) != 0 )
   {
      DBG( puts( "Tilted Right\n" ); )
   
      gSpeedL = SPEED_FWD;
      gSpeedR = SPEED_BWD;
   }
   else
   if (( gTiltState & TILTED_BACK ) != 0 )
   {
      DBG( puts( "Tilted Back\n" ); )

      if ( gHuntDir == HUNT_RIGHT )
      {
         // Target is probably to the right. Back away
         // to the right.

         gSpeedL = SPEED_BWD;
         gSpeedR = SPEED_FWD;
      }
      else
      {
         // Target is probably to the left. Back away
         // to the left.

         gSpeedL = SPEED_FWD;
         gSpeedR = SPEED_BWD;
      }
   }
   else
   {
      DBG( puts( "Tilt Unknown\n" ); )
   
      gSpeedL = SPEED_FWD;
      gSpeedR = SPEED_BWD;
   }

   DBG( puts( "AvoidTilt: Turning away\n" ); )

   for ( i = 0; i < 30; i++ ) 
   {
      PulseMotors();
      WaitForTimer0Rollover();
   }

   DBG( puts( "AvoidTilt: Backing up\n" ); )

   gSpeedL = SPEED_BWD;
   gSpeedR = SPEED_BWD;
   
   for ( i = 0; i < 30; i++ ) 
   {
      PulseMotors();
      WaitForTimer0Rollover();
   }

} // AvoidTilt

