/****************************************************************************
*
*  DebugKey.c
*
*  Debug Processing of a character
*
****************************************************************************/

#pragma chip PIC16F877

#define  DEBUG 1

#include "DebugKey.h"
#include "Delay.h"
#include "Motor.h"
#include "Puts.h"
#include "Sensor.h"
#include "Tilt.h"

#if DEBUG

uns8  gRunMotors;
uns8  gDoneDebugKey;

#define  DEBUG_LEFT_MOTOR  1
#define  DEBUG_RIGHT_MOTOR 2
#define  DEBUG_BOTH_MOTORS 3

uns8  gDebugMotor;
uns8  gDebugCounter;

#if USE_TILT
uns8  gDebugTilt;
#endif

#pragma  bit BUZZER  @ PORTC.5

void Beep( void )
{
   uns8  i;

   for ( i = 0; i < 10; i++  ) 
   {
      BUZZER = 0;
      Delay100uSec( 5 );

      BUZZER = 1;
      Delay100uSec( 5 );
   }

   BUZZER = 0;

} // Beep

extern void DebugKey( uns8 ch )
{
   gRunMotors = 0;
   gDoneDebugKey = 0;

   gDebugCounter = 0;
#if USE_TILT
   gDebugTilt = 0;
#endif

   puts( "\nDebugKey\n" );
   
   while ( !gDoneDebugKey )
   {
      if ( RCIF == 1 )
      {
         ch = RCREG;

         switch ( ch )
         {
            case ' ':
            {
               puts( "Go\n" );
               gDoneDebugKey = 1;
               break;
            }

            case '.':
            {
                uns8    maxRamp = 1 << RAMP_SHIFT;

                if ( gRampDelta < maxRamp )
                {
                    gRampDelta <<= 1;
                }
                puts( "RampDelta = " );
                putu8( gRampDelta );
                puts( "\n" );
                break;
            }

            case ',':
            {
                if ( gRampDelta > 1 )
                {
                    gRampDelta >>= 1;
                }
                puts( "RampDelta = " );
                putu8( gRampDelta );
                puts( "\n" );
                break;
            }

            case 'b':
            {
                putc( 'B' );
                gDebugMotor = DEBUG_BOTH_MOTORS;
                break;
            }

            case 'c':   // Calibrate Servos
            {
               puts( "Calibrate Servos\n" );

               gRunMotors = 1;
               gSpeedL = SPEED_OFF;
               gSpeedR = SPEED_OFF;
               break;
            }

            case 'l':
            {
               putc( 'L' );
               gDebugMotor = DEBUG_LEFT_MOTOR;
               break;
            }
         
            case 'r':
            {
               putc( 'R' );
               gDebugMotor = DEBUG_RIGHT_MOTOR;
               break;
            }

            case 's':
            {
               Beep();
               break;
            }

#if USE_TILT
            case 't':
            {
               gDebugTilt = 1 - gDebugTilt;
               puts( "Reading Tilt: " );
               if ( gDebugTilt )
               {
                  puts( "On\n" );
               }
               else
               {
                  puts( "Off\n" );
               }
               break;
            }
#endif

            case '0':
            {
               putc( ch );

               gRunMotors = 0;
               break;
            }

            case '1':
            case '2':
            case '3':
            case '4':
            case '5':
            case '6':
            case '7':
            case '8':
            case '9':
            {
               putc( ch );

               gRunMotors = 1;
               if ( gDebugMotor & DEBUG_LEFT_MOTOR )
               {
                  // 1 = 142, 9 = 158

                  gSpeedL = ( ch - '0' );
                  gSpeedL *= 2;
                  gSpeedL += 140;
               }
               if ( gDebugMotor & DEBUG_RIGHT_MOTOR )
               {
                   // 1 = 142, 9 = 158

                  gSpeedR = ( ch - '0' );
                  gSpeedR *= 2;
                  gSpeedR += 140;
               }
               break;
            }
         }
      }

#if USE_TILT
      if ( gDebugTilt )
      {
         if (( gDebugCounter & 0x0F ) == 0 )
         {
            gTiltX = 0;
            gTiltY = 0;

            ReadTiltSensor();

            gDeferredNewline = 0;

            puts( "\rTilt X: " );
            putu8( gTiltX );
            puts( " Y: " );
            putu8( gTiltY );

            gDeferredNewline = 1;
         }
      }
#endif

      ReadSensors();

      if (( gDebugCounter & 0x0F ) == 0 )
      {
         gDeferredNewline = 0;

         puts( "\rL[ " );
         putu8( gLineL );
         puts( " " );
         putu8( gLineCL );
         puts( " " );
         putu8( gLineC );
         puts( " " );
         putu8( gLineCR );
         puts( " " );
         putu8( gLineR );
         puts( " ]R " );

         if ( PGM_SELECT )
         {
            puts( "1" );
         }
         else
         {
            puts( "0" );
         }
         if ( HUNT_SELECT )
         {
            puts( "1" );
         }
         else
         {
            puts( "0" );
         }

         puts( " EL: " );
         putu8( gEyeL );
         puts( " ER: " );
         putu8( gEyeR );

         puts( " IR: " );
         putu8( gIrDetected );
         puts( " (" );
         putu8( gDetectCount );
         puts( ") SL: " );
         putu8( gSpeedL );
         puts( " SR: " );
         putu8( gSpeedR );
#if USE_TILT
         puts( " TX: " );
         putu8( gTiltX );
         puts( " TY: " );
         putu8( gTiltY );
#endif

         gDeferredNewline = 1;
      }
      
      if ( gRunMotors )
      {
         PulseMotors();
      }
      
      WaitForTimer0Rollover();
      gDebugCounter++;
   }

} // DebugKey

#else

void DebugKeyDummy( void )
{
   ;
}

#endif   // DEBUG
