/****************************************************************************
*
*  Init.c
*
****************************************************************************/

#pragma chip PIC16F877

#include "Init.h"

extern void InitializeChip( void )
{
   // TRISx bits 0 = Output, 1 = Input
   //
   // RA5   I A5/LSCL
   // RA4   I A4/LSDA
   // RA3   I EyeL
   // RA2   I EyeR
   // RA1   I A1
   // RA0   I Pyro

   PORTA = 0b00000000;
   TRISA = 0b00111111;

   // RB7   I YAxis/RTS
   // RB6   I XAxis/CTS
   // RB5   I B5
   // RB4   O PWM4
   // RB3   O PWM3
   // RB2   O PWM2/ServoL
   // RB1   O PWM1/ServoR
   // RB0   I /INT

   PORTB = 0b00000000;
   TRISB = 0b11100001;

   // RC7   I Rx
   // RC6   O Tx       
   // RC5   O Buzzer    SDO
   // RC4   I SDA       SDI
   // RC3   I SCL       SCK
   // RC2   O C2        CCP1
   // RC1   O C1        T1osi/CCP2
   // RC0   I C0        T1oso/T1clk

   TRISC = 0b10011001;
   PORTC = 0b00000000;

   // Port D is D0-D7
   //
   // I have a SPDT switch hooked up to D0/1/2 and D5/6/7

   PORTD = 0b00100001;
   TRISD = 0b01000010;

   // RE2   I LineL     AN7
   // RE1   I LineC     AN6
   // RE0   I LineR     AN5

   PORTE = 0b00000000;
   TRISE = 0b00000111;

   // ADCON1
   // bit 7 ADFM  0 = Left justified, 1 = right justified
   // bit 0-3 determines pin configuration 0b000 = AN0 thru AN7 are all inputs

   ADCON1 = 0b00000000;

   // OPTION register
   //
   // 7  /RBPU    Port B Pull-up enable (1 = disabled, 0 = enabled)
   // 6  INTEDG   Interrupt Edge Select, 1 = rising edge of RB0/INT pin
   // 5  T0CS     TMR0 Clock Select, 0 = Fosc/4, 1 = RA4/T0CKI pin
   // 4  T0SE     TMR0 Source Edge, 0 = rising 1 = falling (on RA4/T0CKI pin)
   // 3  PSA      Prescalar assignment, 0 = PS for TMR0, 1 = PS for WatchDogTimer
   // 2  PS2      0-7 chooses 2 thru 256 for TMR0, 1 thru 128 for WDT
   // 1  PS1
   // 0  PS0

   OPTION = 0b01000111; // TMR0 = 76.3 ticks per second

   // INTCON Interrupt Configuration Register
   //
   // 7  GIE   Global Interrupt Enable    0 = disable    1 = enable
   // 6  PEIE  Periperal Interrupt Enable 0 = disable    1 = enable
   // 5  T0IE  TMR0 Interrupt Enable      0 = disable    1 = enable
   // 4  INTE  RB0/INT Interrupt Enable   0 = disable    1 = enable
   // 3  RBIE  RB Port Change IE          0 = disable    1 = enable
   // 2  T0IF  TMR0 Overflow Flag         1 = timer 0 overflowed
   // 1  INTF  RB0/INT Ext Int Flag       1 = interrupt detected
   // 0  RBIF  RB Port Change Int Flag    1 = RB Port state change detected

   INTCON = 0b00000000;

   // Configure CCP1 to be in PWM mode for the IR Detector.

   PR2 = 130;  // With TMR2 prescalar set to 1:1 this is a 38 kHz signal

   CCPR1L = 65;   // 50% duty cycle

   // T2CON - Timer 2 Control
   //
   // 7  Unused
   // 6  TOUTPS3  PostScalar selection
   // 5  TOUTPS2
   // 4  TOUTPS1
   // 3  TOUTPS0
   // 2  TMR2ON   0 = Off, 1 = On
   // 1  T2CKPS1  Prescalar selection
   // 0  T2CKPS0

   T2CON = 0b00000100;

   // CCP1CON
   //
   // 7  Unused
   // 6  Unused
   // 5  CCP1X    2 LSBs of CCPR1L
   // 4  CCP1Y 
   // 3  CCP1M3   CCP1 Mode Select Bits
   // 2  CCP1M2
   // 1  CCP1M1
   // 0  CCP1M0

   CCP1CON = 0b00001111;   // PWM Mode

} // InitializeChip

