/****************************************************************************
*
*  Print.c
*
*  Routines for outputting strings.
*
****************************************************************************/

#pragma chip PIC16F877

// ---- Include Files -------------------------------------------------------

#include "Debug.h"
#include "Motor.h"
#include "Print.h"
#include "Sensor.h"

// ---- Public Variables ----------------------------------------------------

uns8        gDeferredNewline;

const char *gStr;

#define  putc( c )   while ( TXIF == 0 ); TXREG = c
#define  puts( x )   gStr = x; PrintStr()

// ---- Private Constants and Types -----------------------------------------
// ---- Private Variables ---------------------------------------------------
// ---- Private Function Prototypes -----------------------------------------
// ---- Functions -----------------------------------------------------------

/****************************************************************************
*
*  Writes a string the serial port.
*/

void PrintStr( void )
{
   if ( gDeferredNewline )
   {
      putc( '\r' );
      putc( '\n' );
      gDeferredNewline = 0;
   }

   while ( *gStr )
   {
      if ( *gStr == '\n' )
      {
         putc( '\r' );         
      }

      putc( *gStr );

      gStr++;
   }

} // PrintStr

/****************************************************************************
*
*  Writes an integer in ASCII form to the serial port
*/

void putu8( uns8 num )
{
   char  buf[ 4 ];
   int   i = 0;

   do
   {
      uns8  c;

      c = num % 10;
      c += '0';
      
      buf[ i ] = c;
      i++;
      num /= 10;
      
   } while ( num != 0 );

   while ( i < 3 )
   {
      buf[ i ] = ' ';
      i++;
   }
   
   while ( i > 0 )
   {
      i--;

      putc( buf[ i ]);
   }

} // putu8

/***************************************************************************/

extern void PrintAvoidEdgeBackup( void )
{
   puts( "Avoid Edge: Backing up\n" );

} // PrintAvoidEdgeBackup

/***************************************************************************/

extern void PrintAvoidEdgeTurning( void )
{
   puts( "Avoid Edge: Turning\n" );

} // PrintAvoidEdgeTurning

/***************************************************************************/

extern void PrintEyeState( void )
{
#if DEBUG
   if ( gEyeState != gPrevEyeState )
   {
      puts( "EyeState changed: " );
      if (( gEyeState & EYE_DETECTED_LEFT ) != 0 )
      {
         putc( 'L' );
      }
      else
      {
         putc( ' ' );
      }
      if (( gEyeState & EYE_DETECTED_RIGHT ) != 0 )
      {
         putc( 'R' );
      }
      else
      {
         putc( ' ' );
      }
      puts( " EyeL:" );
      putu8( gEyeL );
      puts( " EyeR:" );
      putu8( gEyeR );
      puts( "\n" );

      gPrevEyeState = gEyeState;
   }
#endif

} // PrintEyeState

/***************************************************************************/

extern void PrintGo( void )
{
   puts( "Go\n" );

} // PrintGo

/***************************************************************************/

extern void PrintHuntState( uns8 huntState )
{
   puts( "Hunt: " );

   switch ( huntState )
   {
      case HUNT_STATE_SPIN_LEFT:
      {
         puts( "Spin Left\n" );
         break;
      }

      case HUNT_STATE_SPIN_RIGHT:
      {
         puts( "Spin Right\n" );
         break;
      }

      case HUNT_STATE_GO_STRAIGHT:
      {
         puts( "Go Forward\n" );
         break;
      }

      default:
      {
         puts( "*** Unknown ***\n" );
         break;
      }
   }

} // PrintHuntState

/***************************************************************************/

extern void PrintLineLDetected( void )
{
   puts( "LineL detected\n" );

} // PrintLineLDetected

/***************************************************************************/

extern void PrintLineRDetected( void )
{
   puts( "LineR detected\n" );

} // PrintLineLDetected

/****************************************************************************
*
*  Print the initial line sensor values and the calculated
*  threshold.
*/

extern void PrintLineSetup( void )
{
#if DEBUG && 0
   puts( "Line L:" );
   putu8( gLineL );
   puts( " C:" );
   putu8( gLineC );
   puts( " R:" );
   putu8( gLineR );
   puts( " Thresh:" );
   putu8( gLineThresh );
   puts( "\n" );
#endif

} // PrintLineSetup

/****************************************************************************
*
*  Print the Motor speed, if it changes
*/

extern void PrintMotorSpeed( void )
{
#if DEBUG
   if (( gSpeedL != gPrevSpeedL ) || ( gSpeedR != gPrevSpeedR ))
   {
      puts( "PulseMotors L:" );
      putu8( gSpeedL );
      puts( " R:" );
      putu8( gSpeedR );
      puts( " t0:" );
      putu8( gT0 );
      puts( " t1:" );
      putu8( gT1 );
      puts( "\n" );

      gPrevSpeedL = gSpeedL;
      gPrevSpeedR = gSpeedR;
   }
#endif

} // PrintMotorSpeed

/***************************************************************************/

extern void PrintPaused( void )
{
   puts( "Paused\n" );

} // PrintPaused

/****************************************************************************
*
*  Print the Sensor values
*/

extern void PrintSensors( void )
{
   gDeferredNewline = 0;

   puts( "\rLL: " );
   putu8( gLineL );
   puts( " LR: " );
   putu8( gLineR );

   puts( " EL: " );
   putu8( gEyeL );
   puts( " ER: " );
   putu8( gEyeR );

   puts( " IR: " );
   putu8( gIrDetected );
   puts( " (" );
   putu8( gDetectCount );
   puts( ") SL: " );
   putu8( gSpeedL );
   puts( " SR: " );
   putu8( gSpeedR );

   gDeferredNewline = 1;

} // PrintSensors

