/****************************************************************************
*
*  Sensor.c
*
*  ReadSensors routine.
*
****************************************************************************/

#pragma chip PIC16F877

// ---- Include Files -------------------------------------------------------

#include "a2d.h"
#include "Delay.h"
#include "Sensor.h"
#include "Puts.h"

// ---- Private Constants and Types -----------------------------------------

#pragma  bit IR_DETECT  @ PORTB.5
   
// ---- Private Variables ---------------------------------------------------

uns8  gLineL;
uns8  gLineC;
uns8  gLineR;
uns8  gLineCL;
uns8  gLineCR;

uns16 gEyeL;
uns16 gEyeR;

uns8  gIrDetected;
uns8  gDetectCount;

// ---- Private Function Prototypes -----------------------------------------
// ---- Functions -----------------------------------------------------------

/***************************************************************************
*
*  ReadSensors
*
*  Reads the various sensors
*/

extern void ReadSensors( void )
{  
   uns8  i;

#if USE_TILT
   // Read the Tilt Sensor

   ReadTiltSensor();
#endif
   
   // Read the IR Detector

   gDetectCount = 0;
   gIrDetected = 0;
   for ( i = 0; i < 20; i++ ) 
   {
      // A zero on IR_DETECT means that we're detecting, 
      // a 1 means we're not.

      if ( !IR_DETECT )
      {
         gDetectCount++;
      }
      Delay100uSec( 1 );
   }
   if ( gDetectCount > 15 )
   {
      gIrDetected = 1;
   }

   // Read the line sensors

   gLineR  = a2d( LINE_R );
   gLineL  = a2d( LINE_L );
   gLineC  = a2d( LINE_C );
   gLineCL = a2d( LINE_CL );
   gLineCR = a2d( LINE_CR );

   // Read the Eye sensors

   gEyeR = a2d( EYE_R );
   gEyeL = a2d( EYE_L );

#if 0
   puts( "ReadSensors called\n" );
   puts( "LineL: " );
   putu8( gLineL );
   puts( "\n" );
#endif

} // ReadSensors

