/****************************************************************************
*
*  Tilt.c
*
*  Reads the tilt sensor
*
****************************************************************************/

#pragma chip PIC16F877

// ---- Include Files -------------------------------------------------------

#include "Tilt.h"
#include "Delay.h"
#include "Puts.h"

// ---- Public Variables ----------------------------------------------------

uns8  gTiltX;
uns8  gTiltY;
uns8  gTiltState;

// ---- Private Constants and Types -----------------------------------------

#define  TILT_THRESH_X_BACK   180
#define  TILT_THRESH_Y_LEFT   75
#define  TILT_THRESH_Y_RIGHT  150

// ---- Private Variables ---------------------------------------------------

#pragma  bit   PWM3     @ PORTB.3
#pragma  bit   PWM4     @ PORTB.4

#pragma  bit   TILT_X   @ PORTB.6
#pragma  bit   TILT_Y   @ PORTB.7

// ---- Private Function Prototypes -----------------------------------------
// ---- Functions -----------------------------------------------------------

/****************************************************************************
*
*  Reads the Tilt sensor.
*/

extern void ReadTiltSensor( void )
{
   gTiltX = 0;
   gTiltY = 0;

   // Wait for both to be 0

   while (( TILT_X != 0 ) || ( TILT_Y != 0 ))
   {
      ;
   }

   // We read both sensors at the same time, so wait for one
   // to become 1.

   while (( TILT_X == 0 ) && ( TILT_Y == 0 ))
   {
      ;
   }

   while (( TILT_X != 0 ) || ( TILT_Y != 0 ))
   {
      if ( TILT_X )
      {
         if ( gTiltX < 255 )
         {
            gTiltX++;
         }
      }

      if ( TILT_Y )
      {
         if ( gTiltY < 255 )
         {
            gTiltY++;
         }
      }
   }

   // Set the state based on the tilt values.

   gTiltState = 0;

   if ( gTiltX >= TILT_THRESH_X_BACK )
   {
      gTiltState |= TILTED_BACK;   
   }
   if ( gTiltY <= TILT_THRESH_Y_LEFT )
   {
      gTiltState |= TILTED_LEFT;  
   }
   if ( gTiltY >= TILT_THRESH_Y_RIGHT )
   {
      gTiltState |= TILTED_RIGHT;
   }

} // ReadTiltSensor

